
 ****************************** Prepare files **************************

  program preparefiles
 	local stage `1'
 	local silent `2'
	****  CODEBOOK FOR SILENT:
	*   1 -> Nice stata output display
	*   0 -> Display everything 

  ******  Local variables to run the stuff quietly or noisily	
  
	if `silent'==1 {
		local sil "qui"
		local noi " "
	}
	else {
		local sil " "
		local noi "qui"
	}

  ****** Local variables that tell which tables are going to be done
  
	forvalues t=1/2 {
		local stage`t'=0
	}
	local dojoint=0
	if " `stage'"==" 1 2" {
		local dojoint=1
	}
	while "`stage'"!="" {
		gettoken s stage: stage
		local stage`s'=1
	}
	
  
  ******* Program starts
  
  	di " "
	di "   Prepare files will all relevant dummies and interactions", as text
	di "---------------------------------------------------------------------------"
	
	forvalues regional=0/1 {
			
		if `regional'==0 {
			di "   Aggregated Data:", as text
			local dataterm ""
			local ident "cntry"
		}
		else if `regional'==1 {
			di "   Regional Data:", as text   
			local dataterm "_region"
			local ident "region"
		}


		  ****** First stage

		if `stage1'==1 {

			di "             First stage", as text _continue
															
			local path="$data"
			use "`path'Shares`dataterm'.dta", clear
			
			di ".", as text _continue


			local path="$prepared"
			`sil' merge m:1 `ident' period using "`path'Instrument`dataterm'.dta"
			
			di ".", as text _continue
				
			`sil' replace wt=1 if share==.
			`sil' replace share=0 if share==.
			drop _merge

			di ".", as text _continue
															
			if `regional'==0 {
				`sil' replace ldist_disasters_affected=ldist_disasters_affected/1000			
			}
			else if `regional'==1 {
				drop cntry
				rename region cntry
			}
			
			di ".", as text _continue

			`sil' gendummies "`regional'"

			di ".", as text _continue

			`sil' geninteract "`regional'"

			di ".", as text
			
			`sil' drop if sex==2
			`sil' drop if cntry==380
			`sil' egen totwtoth=sum(wt * (cntry!=840 & cntry!=124))
			`sil' egen totwtuscan=sum(wt * (cntry==840 | cntry==124))
			`sil' gen wt2=wt/(totwtoth * (cntry!=840 & cntry!=124) + ///
							totwtuscan * (cntry==840 | cntry==124))
			drop totwtoth totwtuscan

			local path="$prepared"
			`sil' save "`path'First_stage`dataterm'.dta", replace
			
		}
		
		
		  ****** Second stage

		if `stage2'==1 {
 
			di "             Second stage", as text _continue
															
			local path="$data"
			`sil' use "`path'Wages`dataterm'.dta", clear
			di ".", as text _continue
			
			local path="$data"
			`sil' merge 1:m sex education experience `ident' sample period using "`path'Shares`dataterm'.dta"
			`sil' keep if _merge==3
			drop _merge
			
			`sil' gen male_balanced=(balanced==1 & sex==1)
			`sil' label define yesno 0 "No" 1 "Yes"
			`sil' label values male_balanced yesno
			di ".", as text _continue
			
			`sil' gen male_unbalanced=(sex==1)
			`sil' label values male_unbalanced yesno
		
			if `regional'==1 {
				drop cntry
				rename region cntry
			}
			`sil' gendummies "`regional'"
			di ".", as text
			
			`sil' drop if sex==2

			local path="$prepared"
			`sil' save "`path'Second_stage`dataterm'.dta", replace
		
		}
		
		if `dojoint'==1 {
			di "             Merge them", as text _continue
			local path="$prepared"
			`sil' use "`path'First_stage`dataterm'.dta", clear
			di ".", as text _continue
			
			local path="$prepared"
			`sil' merge 1:1 cntry sample sex education experience period using "`path'Second_stage`dataterm'.dta"
			`sil' drop _merge
			di ".", as text _continue
			
			local path="$prepared"
			`sil' save "`path'All_data`dataterm'.dta", replace
			di ".", as text
		}
		
	}

  end
  
  

  
